Installation
============
The most recent release can be installed from
`PyPI <https://pypi.org/project/autoreviewer>`_ with:

.. code-block:: shell

    $ pip install autoreviewer

The most recent code and data can be installed directly from GitHub with:

.. code-block:: shell

    $ pip install git+https://github.com/cthoyt/autoreviewer.git

To install in development mode, use the following:

.. code-block:: shell

    $ git clone git+https://github.com/cthoyt/autoreviewer.git
    $ cd autoreviewer
    $ pip install -e .
